@@ -1,8 +1,5 @@
-use sauron::{
-    node,
-    Node,
-    Render,
-};
+use sauron::prelude::*;
+use sauron::{node, Node, Render};
 
 #[test]
 fn style_should_be_valid() {
@@ -12,3 +9,13 @@ fn style_should_be_valid() {
     node1.render(&mut buffer).expect("must have no error");
     assert_eq!(expected, buffer);
 }
+
+#[test]
+fn must_compile() {
+    let result: Node<()> = node! {
+        <div id="hello">"Hello world"</div>
+    };
+
+    let expected = div(vec![id("hello")], vec![text("Hello world")]);
+    assert_eq!(expected, result);
+}
